=======
History
=======

0.2.0 (2017-06-29)
------------------

* Changed dataset_contents function to filter out empty fields by default
* Got documentation running on RTD, and continuous integration running on TravisCI

0.1.0 (2017-06-21)
------------------

* Initial release on PyPI.
